list/adt.hpp

The list/adt.hpp header defines basic operations for manipulating lists.

#### Usage

#include <boost/preprocessor/list/adt.hpp>

#### Contents

- BOOST_PP_LIST_CONS
- BOOST_PP_LIST_FIRST
- BOOST_PP_LIST_IS_CONS
- BOOST_PP_LIST_IS_NIL
- BOOST_PP_LIST_NIL
- BOOST_PP_LIST_REST

© Copyright Housemarque Oy 2002 © Copyright Paul Mensonides 2002

Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at www.boost.org/LICENSE_1_0.txt)